==> net.bluemind.p2.platform-4.9.3879.zip: net/bluemind/system/api/hot/upgrade/gwt/endpoint/InternalHotUpgradeSockJsEndpoint.java <==
/* BEGIN LICENSE
 * Copyright Â© Blue Mind SAS, 2012-2016
 *
 * This file is part of BlueMind. BlueMind is a messaging and collaborative
 * solution.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of either the GNU Affero General Public License as
 * published by the Free Software Foundation (version 3 of the License).
 *
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * See LICENSE.txt
 * END LICENSE
 */
package net.bluemind.system.api.hot.upgrade.gwt.endpoint;

import net.bluemind.core.api.AsyncHandler;
import net.bluemind.core.commons.gwt.EndpointRequestCallback;
import net.bluemind.core.commons.gwt.GwtSerDerUtils;

import com.google.gwt.core.client.JavaScriptObject;
import com.google.gwt.json.client.JSONValue;
import com.google.gwt.json.client.JSONObject;
import net.bluemind.restbus.api.gwt.AsyncHandlerAdapter;
import java.util.List;
import java.util.Map;
import java.util.Set;
import net.bluemind.core.api.Stream;
import java.lang.Long;
import net.bluemind.restbus.api.gwt.GwtRestRequest;
import net.bluemind.restbus.api.gwt.GwtRestResponse;
import net.bluemind.restbus.api.gwt.RestBusImpl;

public class InternalHotUpgradeSockJsEndpoint implements net.bluemind.system.api.hot.upgrade.IInternalHotUpgradeAsync {

	private String rootUri = "/api";

	private String baseUri;

    private String sessionId;

	public InternalHotUpgradeSockJsEndpoint(String sessionId, String... pathVars) {
		String uri_ = "/hot_upgrade";
		this.sessionId = sessionId;
	

		baseUri = uri_;
	}

	public InternalHotUpgradeSockJsEndpoint withRoot(String root) {
		this.rootUri = root;
		return this;
	}

	@Override
	public void running(final AsyncHandler<Set<net.bluemind.system.api.hot.upgrade.HotUpgradeTask>> handler) {
		String postUri = "/running";

		String uri_ = baseUri + postUri;

		Map<String,String> params = new java.util.HashMap<>();
		JavaScriptObject bodyContent = null;

		 GwtRestRequest request = net.bluemind.restbus.api.gwt.GwtRestRequest.create(sessionId,"GET",rootUri + uri_,params, bodyContent);
		
		request.getHeaders().put("Accept", "application/json");
		RestBusImpl.get().sendMessage(request, new AsyncHandlerAdapter<Set<net.bluemind.system.api.hot.upgrade.HotUpgradeTask>>(handler) {
					@Override
			protected Set<net.bluemind.system.api.hot.upgrade.HotUpgradeTask> handleResponse(
							JSONValue jsonValue) {
				return new GwtSerDerUtils.SetSerDer<>(new net.bluemind.system.api.hot.upgrade.gwt.serder.HotUpgradeTaskGwtSerDer()).deserialize( jsonValue );
			}
		});

	}


	@Override
	public void progress(final AsyncHandler<List<net.bluemind.system.api.hot.upgrade.HotUpgradeProgress>> handler) {
		String postUri = "/progress";

		String uri_ = baseUri + postUri;

		Map<String,String> params = new java.util.HashMap<>();
		JavaScriptObject bodyContent = null;

		 GwtRestRequest request = net.bluemind.restbus.api.gwt.GwtRestRequest.create(sessionId,"GET",rootUri + uri_,params, bodyContent);
		
		request.getHeaders().put("Accept", "application/json");
		RestBusImpl.get().sendMessage(request, new AsyncHandlerAdapter<List<net.bluemind.system.api.hot.upgrade.HotUpgradeProgress>>(handler) {
					@Override
			protected List<net.bluemind.system.api.hot.upgrade.HotUpgradeProgress> handleResponse(
							JSONValue jsonValue) {
				return new GwtSerDerUtils.ListSerDer<>(new net.bluemind.system.api.hot.upgrade.gwt.serder.HotUpgradeProgressGwtSerDer()).deserialize( jsonValue );
			}
		});

	}


	@Override
	public void list(net.bluemind.system.api.hot.upgrade.HotUpgradeTaskFilter filter, final AsyncHandler<List<net.bluemind.system.api.hot.upgrade.HotUpgradeTask>> handler) {
		String postUri = "/list";

		String uri_ = baseUri + postUri;

		Map<String,String> params = new java.util.HashMap<>();
		JavaScriptObject bodyContent = null;
		JSONValue jsonValue = new net.bluemind.system.api.hot.upgrade.gwt.serder.HotUpgradeTaskFilterGwtSerDer().serialize( filter);
		if( jsonValue != null) {
			bodyContent = jsonValue.isObject().getJavaScriptObject();
		}

		 GwtRestRequest request = net.bluemind.restbus.api.gwt.GwtRestRequest.create(sessionId,"POST",rootUri + uri_,params, bodyContent);
		
		request.getHeaders().put("Accept", "application/json");
		RestBusImpl.get().sendMessage(request, new AsyncHandlerAdapter<List<net.bluemind.system.api.hot.upgrade.HotUpgradeTask>>(handler) {
					@Override
			protected List<net.bluemind.system.api.hot.upgrade.HotUpgradeTask> handleResponse(
							JSONValue jsonValue) {
				return new GwtSerDerUtils.ListSerDer<>(new net.bluemind.system.api.hot.upgrade.gwt.serder.HotUpgradeTaskGwtSerDer()).deserialize( jsonValue );
			}
		});

	}


	@Override
	public void startLimited(long maxDuration, net.bluemind.system.api.hot.upgrade.HotUpgradeTaskExecutionMode mode, final AsyncHandler<net.bluemind.core.task.api.TaskRef> handler) {
		String postUri = "/limitedStart";

		String uri_ = baseUri + postUri;

		Map<String,String> params = new java.util.HashMap<>();
		params.put("maxDuration", ""+maxDuration);
		JavaScriptObject bodyContent = null;
		JSONValue jsonValue = new net.bluemind.system.api.hot.upgrade.gwt.serder.HotUpgradeTaskExecutionModeGwtSerDer().serialize( mode);
		if( jsonValue != null) {
			bodyContent = jsonValue.isObject().getJavaScriptObject();
		}

		 GwtRestRequest request = net.bluemind.restbus.api.gwt.GwtRestRequest.create(sessionId,"POST",rootUri + uri_,params, bodyContent);
		
		request.getHeaders().put("Accept", "application/json");
		RestBusImpl.get().sendMessage(request, new AsyncHandlerAdapter<net.bluemind.core.task.api.TaskRef>(handler) {
					@Override
			protected net.bluemind.core.task.api.TaskRef handleResponse(
							JSONValue jsonValue) {
				return new net.bluemind.core.task.api.gwt.serder.TaskRefGwtSerDer().deserialize( jsonValue );
			}
		});

	}


	@Override
	public void count(net.bluemind.system.api.hot.upgrade.HotUpgradeTaskExcludeOperationFilter filter, final AsyncHandler<Long> handler) {
		String postUri = "/count";

		String uri_ = baseUri + postUri;

		Map<String,String> params = new java.util.HashMap<>();
		JavaScriptObject bodyContent = null;
		JSONValue jsonValue = new net.bluemind.system.api.hot.upgrade.gwt.serder.HotUpgradeTaskExcludeOperationFilterGwtSerDer().serialize( filter);
		if( jsonValue != null) {
			bodyContent = jsonValue.isObject().getJavaScriptObject();
		}

		 GwtRestRequest request = net.bluemind.restbus.api.gwt.GwtRestRequest.create(sessionId,"POST",rootUri + uri_,params, bodyContent);
		
		request.getHeaders().put("Accept", "application/json");
		RestBusImpl.get().sendMessage(request, new AsyncHandlerAdapter<Long>(handler) {
					@Override
			protected Long handleResponse(
							JSONValue jsonValue) {
				return GwtSerDerUtils.LONG.deserialize( jsonValue );
			}
		});

	}


	@Override
	public void start(boolean onlyReady, net.bluemind.system.api.hot.upgrade.HotUpgradeTaskExecutionMode mode, final AsyncHandler<net.bluemind.core.task.api.TaskRef> handler) {
		String postUri = "/start";

		String uri_ = baseUri + postUri;

		Map<String,String> params = new java.util.HashMap<>();
		params.put("onlyReady", ""+onlyReady);
		JavaScriptObject bodyContent = null;
		JSONValue jsonValue = new net.bluemind.system.api.hot.upgrade.gwt.serder.HotUpgradeTaskExecutionModeGwtSerDer().serialize( mode);
		if( jsonValue != null) {
			bodyContent = jsonValue.isObject().getJavaScriptObject();
		}

		 GwtRestRequest request = net.bluemind.restbus.api.gwt.GwtRestRequest.create(sessionId,"POST",rootUri + uri_,params, bodyContent);
		
		request.getHeaders().put("Accept", "application/json");
		RestBusImpl.get().sendMessage(request, new AsyncHandlerAdapter<net.bluemind.core.task.api.TaskRef>(handler) {
					@Override
			protected net.bluemind.core.task.api.TaskRef handleResponse(
							JSONValue jsonValue) {
				return new net.bluemind.core.task.api.gwt.serder.TaskRefGwtSerDer().deserialize( jsonValue );
			}
		});

	}

	public net.bluemind.system.api.hot.upgrade.IInternalHotUpgradePromise promiseApi() {
		return new InternalHotUpgradeEndpointPromise(this);
	}

}

==> net.bluemind.p2.platform-5.5.3184.zip: net/bluemind/system/api/hot/upgrade/gwt/endpoint/InternalHotUpgradeSockJsEndpoint.java <==
/* BEGIN LICENSE
 * Copyright Â© Blue Mind SAS, 2012-2016
 *
 * This file is part of BlueMind. BlueMind is a messaging and collaborative
 * solution.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of either the GNU Affero General Public License as
 * published by the Free Software Foundation (version 3 of the License).
 *
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * See LICENSE.txt
 * END LICENSE
 */
package net.bluemind.system.api.hot.upgrade.gwt.endpoint;

import com.google.gwt.core.client.JavaScriptObject;
import com.google.gwt.http.client.URL;
import com.google.gwt.json.client.JSONValue;
import com.google.gwt.json.client.JSONObject;

import java.util.List;
import java.util.Map;
import java.util.Set;
import java.lang.Long;

import net.bluemind.core.api.AsyncHandler;
import net.bluemind.core.api.Stream;
import net.bluemind.core.commons.gwt.EndpointRequestCallback;
import net.bluemind.core.commons.gwt.GwtSerDerUtils;
import net.bluemind.restbus.api.gwt.AsyncHandlerAdapter;
import net.bluemind.restbus.api.gwt.GwtRestRequest;
import net.bluemind.restbus.api.gwt.GwtRestResponse;
import net.bluemind.restbus.api.gwt.RestBusImpl;

public class InternalHotUpgradeSockJsEndpoint implements net.bluemind.system.api.hot.upgrade.IInternalHotUpgradeAsync {

	private String rootUri = "/api";

	private String baseUri;

    private String sessionId;

	public InternalHotUpgradeSockJsEndpoint(String sessionId, String... pathVars) {
		String uri_ = "/hot_upgrade";
		this.sessionId = sessionId;
	

		baseUri = uri_;
	}

	public InternalHotUpgradeSockJsEndpoint withRoot(String root) {
		this.rootUri = root;
		return this;
	}

	@Override
	public void list(net.bluemind.system.api.hot.upgrade.HotUpgradeTaskFilter filter, final AsyncHandler<List<net.bluemind.system.api.hot.upgrade.HotUpgradeTask>> handler) {
		String postUri = "/list";

		String uri_ = baseUri + postUri;

		Map<String,String> params = new java.util.HashMap<>();
		JavaScriptObject bodyContent = null;
		JSONValue jsonValue = new net.bluemind.system.api.hot.upgrade.gwt.serder.HotUpgradeTaskFilterGwtSerDer().serialize( filter);
		if( jsonValue != null) {
			bodyContent = jsonValue.isObject().getJavaScriptObject();
		}

		 GwtRestRequest request = net.bluemind.restbus.api.gwt.GwtRestRequest.create(sessionId,"POST",rootUri + uri_,params, bodyContent);
		
		request.getHeaders().put("Accept", "application/json");
		RestBusImpl.get().sendMessage(request, new AsyncHandlerAdapter<List<net.bluemind.system.api.hot.upgrade.HotUpgradeTask>>(handler) {
					@Override
			protected List<net.bluemind.system.api.hot.upgrade.HotUpgradeTask> handleResponse(
							JSONValue jsonValue) {
				return new GwtSerDerUtils.ListSerDer<>(new net.bluemind.system.api.hot.upgrade.gwt.serder.HotUpgradeTaskGwtSerDer()).deserialize( jsonValue );
			}
		});

	}


	@Override
	public void progress(final AsyncHandler<List<net.bluemind.system.api.hot.upgrade.HotUpgradeProgress>> handler) {
		String postUri = "/progress";

		String uri_ = baseUri + postUri;

		Map<String,String> params = new java.util.HashMap<>();
		JavaScriptObject bodyContent = null;

		 GwtRestRequest request = net.bluemind.restbus.api.gwt.GwtRestRequest.create(sessionId,"GET",rootUri + uri_,params, bodyContent);
		
		request.getHeaders().put("Accept", "application/json");
		RestBusImpl.get().sendMessage(request, new AsyncHandlerAdapter<List<net.bluemind.system.api.hot.upgrade.HotUpgradeProgress>>(handler) {
					@Override
			protected List<net.bluemind.system.api.hot.upgrade.HotUpgradeProgress> handleResponse(
							JSONValue jsonValue) {
				return new GwtSerDerUtils.ListSerDer<>(new net.bluemind.system.api.hot.upgrade.gwt.serder.HotUpgradeProgressGwtSerDer()).deserialize( jsonValue );
			}
		});

	}


	@Override
	public void running(final AsyncHandler<Set<net.bluemind.system.api.hot.upgrade.HotUpgradeTask>> handler) {
		String postUri = "/running";

		String uri_ = baseUri + postUri;

		Map<String,String> params = new java.util.HashMap<>();
		JavaScriptObject bodyContent = null;

		 GwtRestRequest request = net.bluemind.restbus.api.gwt.GwtRestRequest.create(sessionId,"GET",rootUri + uri_,params, bodyContent);
		
		request.getHeaders().put("Accept", "application/json");
		RestBusImpl.get().sendMessage(request, new AsyncHandlerAdapter<Set<net.bluemind.system.api.hot.upgrade.HotUpgradeTask>>(handler) {
					@Override
			protected Set<net.bluemind.system.api.hot.upgrade.HotUpgradeTask> handleResponse(
							JSONValue jsonValue) {
				return new GwtSerDerUtils.SetSerDer<>(new net.bluemind.system.api.hot.upgrade.gwt.serder.HotUpgradeTaskGwtSerDer()).deserialize( jsonValue );
			}
		});

	}


	@Override
	public void start(boolean onlyReady, net.bluemind.system.api.hot.upgrade.HotUpgradeTaskExecutionMode mode, final AsyncHandler<net.bluemind.core.task.api.TaskRef> handler) {
		String postUri = "/start";

		String uri_ = baseUri + postUri;

		Map<String,String> params = new java.util.HashMap<>();
		params.put("onlyReady", URL.encodeQueryString(""+onlyReady));
		JavaScriptObject bodyContent = null;
		JSONValue jsonValue = new net.bluemind.system.api.hot.upgrade.gwt.serder.HotUpgradeTaskExecutionModeGwtSerDer().serialize( mode);
		if( jsonValue != null) {
			bodyContent = jsonValue.isObject().getJavaScriptObject();
		}

		 GwtRestRequest request = net.bluemind.restbus.api.gwt.GwtRestRequest.create(sessionId,"POST",rootUri + uri_,params, bodyContent);
		
		request.getHeaders().put("Accept", "application/json");
		RestBusImpl.get().sendMessage(request, new AsyncHandlerAdapter<net.bluemind.core.task.api.TaskRef>(handler) {
					@Override
			protected net.bluemind.core.task.api.TaskRef handleResponse(
							JSONValue jsonValue) {
				return new net.bluemind.core.task.api.gwt.serder.TaskRefGwtSerDer().deserialize( jsonValue );
			}
		});

	}


	@Override
	public void startLimited(long maxDuration, net.bluemind.system.api.hot.upgrade.HotUpgradeTaskExecutionMode mode, final AsyncHandler<net.bluemind.core.task.api.TaskRef> handler) {
		String postUri = "/limitedStart";

		String uri_ = baseUri + postUri;

		Map<String,String> params = new java.util.HashMap<>();
		params.put("maxDuration", URL.encodeQueryString(""+maxDuration));
		JavaScriptObject bodyContent = null;
		JSONValue jsonValue = new net.bluemind.system.api.hot.upgrade.gwt.serder.HotUpgradeTaskExecutionModeGwtSerDer().serialize( mode);
		if( jsonValue != null) {
			bodyContent = jsonValue.isObject().getJavaScriptObject();
		}

		 GwtRestRequest request = net.bluemind.restbus.api.gwt.GwtRestRequest.create(sessionId,"POST",rootUri + uri_,params, bodyContent);
		
		request.getHeaders().put("Accept", "application/json");
		RestBusImpl.get().sendMessage(request, new AsyncHandlerAdapter<net.bluemind.core.task.api.TaskRef>(handler) {
					@Override
			protected net.bluemind.core.task.api.TaskRef handleResponse(
							JSONValue jsonValue) {
				return new net.bluemind.core.task.api.gwt.serder.TaskRefGwtSerDer().deserialize( jsonValue );
			}
		});

	}

	public net.bluemind.system.api.hot.upgrade.IInternalHotUpgradePromise promiseApi() {
		return new InternalHotUpgradeEndpointPromise(this);
	}

}
